@@ -7,6 +7,7 @@ import json
 import textwrap
 import traceback
 import typing
+import inspect
 
 import discord
 from discord.ext import commands
@@ -14,45 +15,108 @@ from discord.ext import commands
 from . import utils
 
 
-class OwnerOnly(utils.Cog, command_attrs={'hidden': True}):
+class OwnerOnly(utils.Cog, command_attrs={'hidden': True, 'add_slash_command': False}):
     """
     Handles commands that only the owner should be able to run.
     """
 
+    @commands.command(aliases=['src'], cls=utils.Command)
+    @commands.is_owner()
+    @commands.bot_has_permissions(send_messages=True, attach_files=True, add_reactions=True)
+    async def source(self, ctx:utils.Context, *, command_name:str):
+        """
+        Shows you the source for a given command.
+        """
+
+        command = self.bot.get_command(command_name)
+        if command is None:
+            return await ctx.send(f"I couldn't find a command named `{command_name}`.", allowed_mentions=discord.AllowedMentions.none())
+        data = textwrap.dedent(inspect.getsource(command.callback))
+        lines = data.strip().split("\n")
+        current, last = "", ""
+        pages = []
+        for line in lines:
+            current += f"{line}\n"
+            if len(current) >= 1950:
+                pages.append(f"```py\n{last}\n```")
+                current = line
+            last = current
+        if last:
+            pages.append(f"```py\n{last}\n```")
+
+        message = await ctx.send(pages[0])
+
+        # List of valid emojis the user can react with
+        valid_emoji = [
+            "\N{BLACK LEFT-POINTING TRIANGLE}",
+            "\N{BLACK RIGHT-POINTING TRIANGLE}",
+            "\N{WHITE HEAVY CHECK MARK}"
+        ]
+
+        # Reacts to the initial message with left arrow, right arrow, and check mark
+        for i in valid_emoji:
+            try:
+                await message.add_reaction(i)
+            except discord.HTTPException:
+                return
+
+        # Loops until checkmark is reacted
+        index = 0
+        while True:
+
+            # Checks that author is who typed the command and that the emoji reacted by the user is in validEmoji
+            def check(reaction, user):
+                return user == ctx.author and str(reaction.emoji) in valid_emoji
+
+            # Waits for the reaction from the user
+            try:
+                reaction, _ = await self.bot.wait_for('reaction_add', timeout=300.0, check=check)
+            except asyncio.TimeoutError:
+                reaction.emoji = valid_emoji[2]
+
+            # Checks which emoji was reacted and add to the index
+            if reaction.emoji == valid_emoji[0]:
+                new_index = index + 1
+            if reaction.emoji == valid_emoji[1]:
+                new_index = index - 1
+            if reaction.emoji == valid_emoji[2]:
+                break
+
+            # See if our index has changed
+            new_index = max(0, new_index)
+            new_index = min(len(pages), new_index)
+            if new_index == index:
+                continue
+            index = new_index
+
+            # Update the message
+            try:
+                await message.edit(content=pages[index])
+            except discord.HTTPException:
+                return
+
+        # Removes the reactions from the initial message
+        for i in valid_emoji:
+            try:
+                await message.remove_reaction(i)
+            except discord.HTTPException:
+                pass
+
     @commands.command(aliases=['pm', 'dm', 'send'], cls=utils.Command)
     @commands.is_owner()
     @commands.bot_has_permissions(send_messages=True, add_reactions=True)
-    async def message(
-            self, ctx:utils.Context,  # channel_type:typing.Optional[utils.converters.EnumConverter("channel", "user", "c", "u", case_insensitive=True)],
-            snowflake:typing.Optional[typing.Union[utils.converters.UserID, utils.converters.ChannelID]],
-            *, content:str=None):
+    async def message(self, ctx:utils.Context, snowflake:int, *, content:str=None):
         """
         DMs a user the given content.
         """
 
         # Work out what we're going to use to convert the snowflake
-        channel_type = None  # This is a later issue
-        if channel_type is None:
-            converters = [
-                self.bot.get_user,
-                self.bot.get_channel,
-                self.bot.fetch_user,
-                self.bot.fetch_channel,
-            ]
-        elif channel_type[0] == "u":
-            converters = [
-                self.bot.get_user,
-                self.bot.fetch_user,
-            ]
-        elif channel_type[0] == "c":
-            converters = [
-                self.bot.get_channel,
-                self.bot.fetch_channel,
-            ]
-
-        # Make sure we gave a snowflake
-        if snowflake is None:
-            snowflake = ctx.channel.id
+        converters = [
+            self.bot.get_user,
+            self.bot.get_channel,
+            self.bot.fetch_user,
+            self.bot.fetch_channel,
+        ]
 
         # Let's run our converters baybee
         sendable = None
@@ -186,7 +250,7 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True}):
         else:
             return await ctx.send(text, embeddify=False)
 
-    @commands.command(aliases=['rld'], cls=utils.Command)
+    @commands.command(aliases=['rld', 'rl'], cls=utils.Command)
     @commands.is_owner()
     @commands.bot_has_permissions(send_messages=True)
     async def reload(self, ctx:utils.Context, *cog_name:str):
@@ -225,7 +289,7 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True}):
 
     @commands.command(cls=utils.Command, aliases=['downloadcog', 'dlcog', 'download', 'dl', 'stealcog'])
     @commands.is_owner()
-    async def downloadfile(self, ctx:utils.Context, url:str, file_folder:str=None):
+    async def downloadfile(self, ctx:utils.Context, url:str, file_folder:typing.Optional[str]):
         """Download a cog from github"""
 
         # Convert github link to a raw link and grab contents
@@ -333,10 +397,10 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True}):
 
         pass
 
-    @botuser.command(aliases=['username'], cls=utils.Command)
+    @botuser.command(name='name', aliases=['username'], cls=utils.Command)
     @commands.is_owner()
     @commands.bot_has_permissions(send_messages=True)
-    async def name(self, ctx:utils.Context, *, username:str):
+    async def botuser_name(self, ctx:utils.Context, *, username:str):
         """
         Lets you set the username for the bot account.
         """
@@ -346,10 +410,10 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True}):
         await self.bot.user.edit(username=username)
         await ctx.send('Done.')
 
-    @botuser.command(aliases=['photo', 'image', 'avatar'], cls=utils.Command)
+    @botuser.command(name='avatar', aliases=['photo', 'image', 'picture'], cls=utils.Command)
     @commands.is_owner()
     @commands.bot_has_permissions(send_messages=True)
-    async def picture(self, ctx:utils.Context, *, image_url:str=None):
+    async def botuser_avatar(self, ctx:utils.Context, *, image_url:typing.Optional[str]):
         """
         Lets you set the profile picture of the bot.
         """
@@ -365,10 +429,10 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True}):
         await self.bot.user.edit(avatar=image_content)
         await ctx.send('Done.')
 
-    @botuser.command(aliases=['game'], cls=utils.Command)
+    @botuser.command(name='activity', aliases=['game'], cls=utils.Command)
     @commands.is_owner()
     @commands.bot_has_permissions(send_messages=True)
-    async def activity(self, ctx:utils.Context, activity_type:str, *, name:str=None):
+    async def botuser_activity(self, ctx:utils.Context, activity_type:str, *, name:typing.Optional[str]):
         """
         Changes the activity of the bot.
         """
@@ -379,10 +443,10 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True}):
             return await self.bot.set_default_presence()
         await self.bot.change_presence(activity=activity, status=self.bot.guilds[0].me.status)
 
-    @botuser.command(cls=utils.Command)
+    @botuser.command(name='status', cls=utils.Command)
     @commands.is_owner()
     @commands.bot_has_permissions(send_messages=True)
-    async def status(self, ctx:utils.Context, status:str):
+    async def botuser_status(self, ctx:utils.Context, status:str):
         """
         Changes the online status of the bot.
         """
@@ -459,7 +523,7 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True}):
 
     @commands.group(cls=utils.Group)
     @commands.is_owner()
-    async def export(self, ctx):
+    async def export(self, ctx:utils.Context):
         """
         The parent group for the export commands.
         """
@@ -469,13 +533,13 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True}):
     @export.command(cls=utils.Command, name="commands")
     @commands.bot_has_permissions(send_messages=True, attach_files=True)
     @commands.is_owner()
-    async def export_commands(self, ctx):
+    async def export_commands(self, ctx:utils.Context):
         """
         Exports the commands for the bot as a markdown file.
         """
 
         # Set up output
-        lines = [f"# {self.bot.user.name} Commands"]
+        lines = [f"# {self.bot.user.name} Commands\n"]
 
         # Work out prefix
         prefix = self.bot.config.get('default_prefix', ctx.clean_prefix)
@@ -493,19 +557,19 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True}):
                 continue
 
             # Add lines
-            lines.append(f"## {cog_name}")
+            lines.append(f"## {cog_name}\n")
             for command in visible_commands:
                 lines.append(f"* `{prefix}{command.name} {command.signature}".rstrip() + '`')
                 lines.append(f"\t* {command.help}")
 
         # Output file
-        await ctx.send(file=discord.File(io.StringIO('\n\n'.join(lines)), filename="commands.md"))
+        await ctx.send(file=discord.File(io.StringIO('\n'.join(lines)), filename="commands.md"))
 
     @export.command(cls=utils.Command, name="guild")
     @commands.bot_has_permissions(send_messages=True, attach_files=True)
     @utils.checks.is_config_set('database', 'enabled')
     @commands.is_owner()
-    async def export_guild(self, ctx, guild_id:int=None):
+    async def export_guild(self, ctx:utils.Context, guild_id:typing.Optional[int]):
         """
         Exports data for a given guild from the database.
 
@@ -593,7 +657,7 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True}):
     @commands.bot_has_permissions(send_messages=True, attach_files=True)
     @utils.checks.is_config_set('database', 'enabled')
     @commands.is_owner()
-    async def export_table(self, ctx, table_name:str):
+    async def export_table(self, ctx:utils.Context, table_name:str):
         """
         Exports a given table from the database into a .csv file.
         """
