@@ -1,11 +1,10 @@
 # flake8: noqa
-from . import checks, converters, errors
+from . import checks, converters, errors, interactions
 from .checks import cooldown
 from .context_embed import Embed
 from .custom_bot import Bot
 from .custom_cog import Cog
-from .custom_command import Command
-from .custom_command import Group
+from .custom_command import Command, Group, SubcommandGroup
 from .custom_context import Context
 from .database import DatabaseConnection
 from .redis import RedisConnection
@@ -23,3 +22,7 @@ def command(*args, **kwargs):
 
 def group(*args, **kwargs):
     return _dpy_commands.group(*args, cls=Group, **kwargs)
+
+
+def subcommand_group(*args, **kwargs):
+    return _dpy_commands.group(*args, cls=SubcommandGroup, **kwargs)
