@@ -19,6 +19,7 @@ from .database import DatabaseConnection
 from .redis import RedisConnection
 from .statsd import StatsdConnection
 from .analytics_log_handler import AnalyticsLogHandler
+from . import interactions
 from .. import all_packages as all_vfl_package_names
 
 
@@ -53,6 +54,10 @@ def get_prefix(bot, message:discord.Message):
     return commands.when_mentioned_or(*prefix)(bot, message)
 
 
+class RouteV8(discord.http.Route):
+    BASE = 'https://discord.com/api/v8'
+
+
 class Bot(commands.AutoShardedBot):
     """
     A child of discord.ext.commands.AutoShardedBot to make things a little easier when
@@ -104,6 +109,9 @@ class Bot(commands.AutoShardedBot):
         # Aiohttp session
         self.session: aiohttp.ClientSession = aiohttp.ClientSession(loop=self.loop)
 
+        # Application ID (may not be bot ID)
+        self._application_id = None
+
         # Allow database connections like this
         self.database: DatabaseConnection = DatabaseConnection
         self.database.logger = self.logger.getChild('database')
@@ -219,7 +227,7 @@ class Bot(commands.AutoShardedBot):
 
         return self.get_guild(self.config['support_guild_id']) or await self.fetch_guild(self.config['support_guild_id'])
 
-    def get_invite_link(self, *, scope:str='bot', response_type:str=None, redirect_uri:str=None, guild_id:int=None, **kwargs) -> str:
+    def get_invite_link(self, *, scope:str='bot applications.commands', response_type:str=None, redirect_uri:str=None, guild_id:int=None, **kwargs) -> str:
         """
         Gets the invite link for the bot, with permissions all set properly.
 
@@ -299,22 +307,40 @@ class Bot(commands.AutoShardedBot):
             self.logger.error(f"The webhook set in your config for the event {event_name} is not a valid Discord webhook")
             return None
 
-    async def add_delete_button(self, message:discord.Message, valid_users:typing.List[discord.User], *, delete:typing.List[discord.Message]=None, timeout=60.0, wait:bool=True) -> None:
+    async def get_application_id(self):
+        if self._application_id:
+            return self._application_id
+        app = await self.application_info()
+        self._application_id = app.id
+        return self._application_id
+
+    async def add_delete_button(self, message:discord.Message, valid_users:typing.List[discord.User]=None, *, delete:typing.List[discord.Message]=None, timeout=60.0, wait:bool=False) -> None:
         """
         Adds a delete button to the given message.
 
         Args:
             message (discord.Message): The message you want to add a delete button to.
-            valid_users (typing.List[discord.User]): The users who have permission to use the message's delete button.
+            valid_users (typing.List[discord.User], optional): The users who have permission to use the message's delete button.
             delete (typing.List[discord.Message], optional): The messages that should be deleted on clicking the delete button.
             timeout (float, optional): How long the delete button should persist for.
+            wait (bool, optional): Whether or not to block (via async) until the delete button is pressed.
+
+        Raises:
+            discord.HTTPException: The bot was unable to add a delete button to the message.
         """
 
         # See if we want to make this as a task or not
         if wait is False:
-            self.loop.create_task(self.add_delete_button(message=message, valid_users=valid_users, delete=delete, timeout=timeout))
+            self.loop.create_task(self.add_delete_button(message=message, valid_users=valid_users, delete=delete, timeout=timeout, wait=True))
             return
 
+        # See if we were given a list of authors
+        # This is an explicit check for None rather than just a falsy value;
+        # this way users can still provide an empty list for only manage_messages users to be
+        # able to delete the message.
+        if valid_users is None:
+            valid_users = [message.author]
+
         # Let's not add delete buttons to DMs
         if isinstance(message.channel, discord.DMChannel):
             return
@@ -422,6 +448,62 @@ class Bot(commands.AutoShardedBot):
         async with self.session.post("https://voxelfox.co.uk/discord/chatlog", json=data) as r:
             return await r.text()
 
+    async def add_global_application_command(self, command:interactions.ApplicationCommand) -> None:
+        """
+        Add a global slash command for the bot.
+        """
+
+        application_id = await self.get_application_id()
+        r = RouteV8('POST', '/applications/{application_id}/commands', application_id=application_id)
+        return await self.http.request(r, json=command.to_json())
+
+    async def add_guild_application_command(self, guild:discord.Guild, command:interactions.ApplicationCommand) -> None:
+        """
+        Add a guild-level slash command for the bot.
+        """
+
+        application_id = await self.get_application_id()
+        r = RouteV8('POST', '/applications/{application_id}/guilds/{guild_id}/commands', application_id=application_id, guild_id=guild.id)
+        return await self.http.request(r, json=command.to_json())
+
+    async def get_global_application_commands(self) -> typing.List[interactions.ApplicationCommand]:
+        """
+        Add a global slash command for the bot.
+        """
+
+        application_id = await self.get_application_id()
+        r = RouteV8('GET', '/applications/{application_id}/commands', application_id=application_id)
+        data = await self.http.request(r)
+        return [interactions.ApplicationCommand.from_data(i) for i in data]
+
+    async def get_guild_application_commands(self, guild:discord.Guild) -> typing.List[interactions.ApplicationCommand]:
+        """
+        Add a guild-level slash command for the bot.
+        """
+
+        application_id = await self.get_application_id()
+        r = RouteV8('GET', '/applications/{application_id}/guilds/{guild_id}/commands', application_id=application_id, guild_id=guild.id)
+        data = await self.http.request(r)
+        return [interactions.ApplicationCommand.from_data(i) for i in data]
+
+    async def delete_global_application_command(self, command:interactions.ApplicationCommand) -> None:
+        """
+        Remove a global slash command for the bot.
+        """
+
+        application_id = await self.get_application_id()
+        r = RouteV8('DELETE', '/applications/{application_id}/commands/{command_id}', application_id=application_id, command_id=command.id)
+        return await self.http.request(r)
+
+    async def delete_guild_application_command(self, guild:discord.Guild, command:interactions.ApplicationCommand) -> None:
+        """
+        Remove a guild-level slash command for the bot.
+        """
+
+        application_id = await self.get_application_id()
+        r = RouteV8('DELETE', '/applications/{application_id}/guilds/{guild_id}/commands/{command_id}', application_id=application_id, guild_id=guild.id, command_id=command.id)
+        return await self.http.request(r)
+
     @property
     def owner_ids(self) -> list:
         return self.config['owners']
@@ -449,7 +531,9 @@ class Bot(commands.AutoShardedBot):
         return (dt.now() - self.startup_time).total_seconds()
 
     async def get_context(self, message, *, cls=Context) -> 'discord.ext.commands.Context':
-        """Create a new context object using the utils' Context"""
+        """
+        Create a new context object using the utils' Context.
+        """
 
         return await super().get_context(message, cls=cls)
 
@@ -462,8 +546,9 @@ class Bot(commands.AutoShardedBot):
         """
 
         ext = glob.glob('cogs/[!_]*.py')
-        extensions = [i.replace('\\', '.').replace('/', '.')[:-3] for i in ext]
+        extensions = []
         extensions.extend([f'voxelbotutils.cogs.{i}' for i in all_vfl_package_names])
+        extensions.extend([i.replace('\\', '.').replace('/', '.')[:-3] for i in ext])
         self.logger.debug("Getting all extensions: " + str(extensions))
         return extensions
 
