@@ -16,6 +16,7 @@ class Command(commands.Command):
         super().__init__(*args, cooldown_after_parsing=kwargs.pop('cooldown_after_parsing', True), **kwargs)
         self.ignore_checks_in_help: bool = kwargs.get('ignore_checks_in_help', False)
         self.locally_handled_errors: list = kwargs.get('locally_handled_errors', None)
+        self.add_slash_command: bool = kwargs.get('add_slash_command', True)
 
         # Fix cooldown to be our custom type
         cooldown = self._buckets._cooldown
@@ -150,6 +151,15 @@ class Group(commands.Group):
             kwargs['cls'] = Group
         return super().group(*args, **kwargs)
 
+    def subcommand_group(self, *args, **kwargs):
+        """
+        Add the usual utils.Group to the mix.
+        """
+
+        if 'cls' not in kwargs:
+            kwargs['cls'] = SubcommandGroup
+        return super().group(*args, **kwargs)
+
     async def dispatch_error(self, ctx, error):
         """
         Like how we'd normally dispatch an error, but we deal with local lads
@@ -190,3 +200,11 @@ class Group(commands.Group):
         # Ping the global error handler
         except Exception:
             ctx.bot.dispatch('command_error', ctx, error)
+
+
+class SubcommandGroup(Group):
+    """
+    A subcommand group specifically made so that slash commands can be just a little sexier.
+    """
+
+    pass
